
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef __TOTEM_PL_PARSER_BUILTINS_H__
#define __TOTEM_PL_PARSER_BUILTINS_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "totem-pl-parser.h" */
GType totem_pl_parser_result_get_type (void) G_GNUC_CONST;
#define TOTEM_TYPE_PL_PARSER_RESULT (totem_pl_parser_result_get_type ())
GType totem_pl_parser_type_get_type (void) G_GNUC_CONST;
#define TOTEM_TYPE_PL_PARSER_TYPE (totem_pl_parser_type_get_type ())
GType totem_pl_parser_error_get_type (void) G_GNUC_CONST;
#define TOTEM_TYPE_PL_PARSER_ERROR (totem_pl_parser_error_get_type ())
G_END_DECLS

#endif /* __TOTEM_PL_PARSER_BUILTINS_H__ */

/* Generated data ends here */

